.. EMVA1288 documentation master file, created by
   sphinx-quickstart on Tue Jan 25 13:51:20 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
   :end-before: .. end_of_package_description

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install_link
   datasets/index
   doc_api/emva1288
   tutorial
   examples/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
